#' Package imports
#' 
#' @import ggplot2
#' @import leaflet
#' @import sf
#' @importFrom rlang !!
#' @importFrom rlang .data

NULL

#' Pipe operator
#'
#' See \code{magrittr::\link[magrittr:pipe]{\%>\%}} for details.
#'
#' @name %>%
#' @rdname pipe
#' @keywords internal
#' @export
#' @importFrom magrittr %>%
#' @usage lhs \%>\% rhs
NULL

#' Shiny input
utils::globalVariables("input")

